==> jc-1.4.0.tar.gz: javax/swing/plaf/BorderUIResource__24LineBorderUIResource.h <==
// public class javax.swing.plaf.BorderUIResource$LineBorderUIResource

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 564dabb34efb5ce6 javax_swing_border_AbstractBorder
// @dep_class 4c5a705ca8302ac4 javax_swing_border_LineBorder
// @dep_class ef9943962271d09d javax_swing_plaf_BorderUIResource__24LineBorderUIResource

// header file dependencies
// @dep_header javax_swing_border_LineBorder

#include "javax/swing/border/LineBorder.h"

#ifndef _JC_javax_swing_plaf_BorderUIResource__24LineBorderUIResource_H_
#define _JC_javax_swing_plaf_BorderUIResource__24LineBorderUIResource_H_

// Forward structure declarations
struct _jc_java_awt_Color$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_BorderUIResource__24LineBorderUIResource$sub_refs	_jc_javax_swing_plaf_BorderUIResource__24LineBorderUIResource$sub_refs;
typedef struct _jc_javax_swing_plaf_BorderUIResource__24LineBorderUIResource$sub_nonrefs	_jc_javax_swing_plaf_BorderUIResource__24LineBorderUIResource$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_BorderUIResource__24LineBorderUIResource$refs	_jc_javax_swing_plaf_BorderUIResource__24LineBorderUIResource$refs;
typedef struct _jc_javax_swing_plaf_BorderUIResource__24LineBorderUIResource$nonrefs	_jc_javax_swing_plaf_BorderUIResource__24LineBorderUIResource$nonrefs;
typedef struct _jc_javax_swing_plaf_BorderUIResource__24LineBorderUIResource$object	_jc_javax_swing_plaf_BorderUIResource__24LineBorderUIResource$object;

typedef struct _jc_javax_swing_plaf_BorderUIResource__24LineBorderUIResource$fields_struct	_jc_javax_swing_plaf_BorderUIResource__24LineBorderUIResource$fields_struct;
typedef const struct _jc_javax_swing_plaf_BorderUIResource__24LineBorderUIResource$vmethods	_jc_javax_swing_plaf_BorderUIResource__24LineBorderUIResource$vmethods;
typedef const struct _jc_javax_swing_plaf_BorderUIResource__24LineBorderUIResource$vtable	_jc_javax_swing_plaf_BorderUIResource__24LineBorderUIResource$vtable;
typedef const struct _jc_javax_swing_plaf_BorderUIResource__24LineBorderUIResource$vtype	_jc_javax_swing_plaf_BorderUIResource__24LineBorderUIResource$vtype;

// Class fields structure
struct _jc_javax_swing_plaf_BorderUIResource__24LineBorderUIResource$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_swing_plaf_BorderUIResource__24LineBorderUIResource$fields_struct _jc_javax_swing_plaf_BorderUIResource__24LineBorderUIResource$class_fields;

// Constructors
extern void _jc_javax_swing_plaf_BorderUIResource__24LineBorderUIResource$method$_init$d42470fc2dba686a(_jc_env *, struct _jc_javax_swing_plaf_BorderUIResource__24LineBorderUIResource$object *, struct _jc_java_awt_Color$object *);
extern void _jc_javax_swing_plaf_BorderUIResource__24LineBorderUIResource$method$_init$2dcc40e453a10b84(_jc_env *, struct _jc_javax_swing_plaf_BorderUIResource__24LineBorderUIResource$object *, struct _jc_java_awt_Color$object *, jint);

// Virtual methods structure
struct _jc_javax_swing_plaf_BorderUIResource__24LineBorderUIResource$vmethods {
};

// Vtable
struct _jc_javax_swing_plaf_BorderUIResource__24LineBorderUIResource$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_border_AbstractBorder$vmethods	javax_swing_border_AbstractBorder;
	_jc_javax_swing_border_LineBorder$vmethods	javax_swing_border_LineBorder;
	_jc_javax_swing_plaf_BorderUIResource__24LineBorderUIResource$vmethods	javax_swing_plaf_BorderUIResource__24LineBorderUIResource;
};

// Vtype
struct _jc_javax_swing_plaf_BorderUIResource__24LineBorderUIResource$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_BorderUIResource__24LineBorderUIResource$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_BorderUIResource__24LineBorderUIResource$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_BorderUIResource__24LineBorderUIResource$refs {
    _jc_javax_swing_plaf_BorderUIResource__24LineBorderUIResource$sub_refs	javax_swing_plaf_BorderUIResource__24LineBorderUIResource;
    _jc_javax_swing_border_LineBorder$sub_refs	javax_swing_border_LineBorder;
    _jc_javax_swing_border_AbstractBorder$sub_refs	javax_swing_border_AbstractBorder;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_BorderUIResource__24LineBorderUIResource$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_BorderUIResource__24LineBorderUIResource$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_border_AbstractBorder$sub_nonrefs	javax_swing_border_AbstractBorder;
    _jc_javax_swing_border_LineBorder$sub_nonrefs	javax_swing_border_LineBorder;
    _jc_javax_swing_plaf_BorderUIResource__24LineBorderUIResource$sub_nonrefs	javax_swing_plaf_BorderUIResource__24LineBorderUIResource;
};

// Object instance structure
struct _jc_javax_swing_plaf_BorderUIResource__24LineBorderUIResource$object {
	_jc_javax_swing_plaf_BorderUIResource__24LineBorderUIResource$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_BorderUIResource__24LineBorderUIResource$vtype	*vtype;
	_jc_javax_swing_plaf_BorderUIResource__24LineBorderUIResource$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_BorderUIResource__24LineBorderUIResource$vtype _jc_javax_swing_plaf_BorderUIResource__24LineBorderUIResource$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_BorderUIResource__24LineBorderUIResource, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_BorderUIResource__24LineBorderUIResource$class_object;

#endif	/* _JC_javax_swing_plaf_BorderUIResource__24LineBorderUIResource_H_ */

==> jc-1.4.6.tar.gz: javax/swing/plaf/BorderUIResource__24LineBorderUIResource.h <==
// public class javax.swing.plaf.BorderUIResource$LineBorderUIResource

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 564dabb34efb5ce6 javax_swing_border_AbstractBorder
// @dep_class 4c5a705ca8302ac4 javax_swing_border_LineBorder
// @dep_class ef9943962271d09d javax_swing_plaf_BorderUIResource__24LineBorderUIResource

// header file dependencies
// @dep_header javax_swing_border_LineBorder

#include "javax/swing/border/LineBorder.h"

#ifndef _JC_javax_swing_plaf_BorderUIResource__24LineBorderUIResource_H_
#define _JC_javax_swing_plaf_BorderUIResource__24LineBorderUIResource_H_

// Forward structure declarations
struct _jc_java_awt_Color$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_BorderUIResource__24LineBorderUIResource$sub_refs	_jc_javax_swing_plaf_BorderUIResource__24LineBorderUIResource$sub_refs;
typedef struct _jc_javax_swing_plaf_BorderUIResource__24LineBorderUIResource$sub_nonrefs	_jc_javax_swing_plaf_BorderUIResource__24LineBorderUIResource$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_BorderUIResource__24LineBorderUIResource$refs	_jc_javax_swing_plaf_BorderUIResource__24LineBorderUIResource$refs;
typedef struct _jc_javax_swing_plaf_BorderUIResource__24LineBorderUIResource$nonrefs	_jc_javax_swing_plaf_BorderUIResource__24LineBorderUIResource$nonrefs;
typedef struct _jc_javax_swing_plaf_BorderUIResource__24LineBorderUIResource$object	_jc_javax_swing_plaf_BorderUIResource__24LineBorderUIResource$object;

typedef struct _jc_javax_swing_plaf_BorderUIResource__24LineBorderUIResource$fields_struct	_jc_javax_swing_plaf_BorderUIResource__24LineBorderUIResource$fields_struct;
typedef const struct _jc_javax_swing_plaf_BorderUIResource__24LineBorderUIResource$vmethods	_jc_javax_swing_plaf_BorderUIResource__24LineBorderUIResource$vmethods;
typedef const struct _jc_javax_swing_plaf_BorderUIResource__24LineBorderUIResource$vtable	_jc_javax_swing_plaf_BorderUIResource__24LineBorderUIResource$vtable;
typedef const struct _jc_javax_swing_plaf_BorderUIResource__24LineBorderUIResource$vtype	_jc_javax_swing_plaf_BorderUIResource__24LineBorderUIResource$vtype;

// Class fields structure
struct _jc_javax_swing_plaf_BorderUIResource__24LineBorderUIResource$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_swing_plaf_BorderUIResource__24LineBorderUIResource$fields_struct _jc_javax_swing_plaf_BorderUIResource__24LineBorderUIResource$class_fields;

// Constructors
extern void _jc_javax_swing_plaf_BorderUIResource__24LineBorderUIResource$method$_init$d42470fc2dba686a(_jc_env *, struct _jc_javax_swing_plaf_BorderUIResource__24LineBorderUIResource$object *, struct _jc_java_awt_Color$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_BorderUIResource__24LineBorderUIResource$method$_init$2dcc40e453a10b84(_jc_env *, struct _jc_javax_swing_plaf_BorderUIResource__24LineBorderUIResource$object *, struct _jc_java_awt_Color$object *, jint) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_swing_plaf_BorderUIResource__24LineBorderUIResource$vmethods {
};

// Vtable
struct _jc_javax_swing_plaf_BorderUIResource__24LineBorderUIResource$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_border_AbstractBorder$vmethods	javax_swing_border_AbstractBorder;
	_jc_javax_swing_border_LineBorder$vmethods	javax_swing_border_LineBorder;
	_jc_javax_swing_plaf_BorderUIResource__24LineBorderUIResource$vmethods	javax_swing_plaf_BorderUIResource__24LineBorderUIResource;
};

// Vtype
struct _jc_javax_swing_plaf_BorderUIResource__24LineBorderUIResource$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_BorderUIResource__24LineBorderUIResource$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_BorderUIResource__24LineBorderUIResource$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_BorderUIResource__24LineBorderUIResource$refs {
    _jc_javax_swing_plaf_BorderUIResource__24LineBorderUIResource$sub_refs	javax_swing_plaf_BorderUIResource__24LineBorderUIResource;
    _jc_javax_swing_border_LineBorder$sub_refs	javax_swing_border_LineBorder;
    _jc_javax_swing_border_AbstractBorder$sub_refs	javax_swing_border_AbstractBorder;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_BorderUIResource__24LineBorderUIResource$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_BorderUIResource__24LineBorderUIResource$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_border_AbstractBorder$sub_nonrefs	javax_swing_border_AbstractBorder;
    _jc_javax_swing_border_LineBorder$sub_nonrefs	javax_swing_border_LineBorder;
    _jc_javax_swing_plaf_BorderUIResource__24LineBorderUIResource$sub_nonrefs	javax_swing_plaf_BorderUIResource__24LineBorderUIResource;
};

// Object instance structure
struct _jc_javax_swing_plaf_BorderUIResource__24LineBorderUIResource$object {
	_jc_javax_swing_plaf_BorderUIResource__24LineBorderUIResource$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_BorderUIResource__24LineBorderUIResource$vtype	*vtype;
	_jc_javax_swing_plaf_BorderUIResource__24LineBorderUIResource$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_BorderUIResource__24LineBorderUIResource$vtype _jc_javax_swing_plaf_BorderUIResource__24LineBorderUIResource$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_BorderUIResource__24LineBorderUIResource, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_BorderUIResource__24LineBorderUIResource$class_object;

#endif	/* _JC_javax_swing_plaf_BorderUIResource__24LineBorderUIResource_H_ */
